@@ -1,24 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# This file is part of fteproxy.
-#
-# fteproxy is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# fteproxy is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with fteproxy.  If not, see <http://www.gnu.org/licenses/>.
+
 
 import unittest
 
 import fteproxy.record_layer
+import fteproxy.regex2dfa
 
 import fte.encoder
 
@@ -39,7 +27,7 @@ class Tests(unittest.TestCase):
         for language in definitions.keys():
             regex = fteproxy.defs.getRegex(language)
             fixed_slice = fteproxy.defs.getFixedSlice(language)
-            regex_encoder = fte.encoder.RegexEncoder(regex, fixed_slice)
+            regex_encoder = fte.encoder.DfaEncoder(fteproxy.regex2dfa.regex2dfa(regex), fixed_slice)
             encoder = fteproxy.record_layer.Encoder(
                 encoder=regex_encoder)
             decoder = fteproxy.record_layer.Decoder(
